==> istio-model-v1beta1-6.3.1-sources.jar: io/fabric8/istio/api/security/v1beta1/AuthorizationPolicyProviderFluentImpl.java <==
package io.fabric8.istio.api.security.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class AuthorizationPolicyProviderFluentImpl<A extends AuthorizationPolicyProviderFluent<A>> extends BaseFluent<A> implements AuthorizationPolicyProviderFluent<A>{
  public AuthorizationPolicyProviderFluentImpl() {
  }
  public AuthorizationPolicyProviderFluentImpl(AuthorizationPolicyProvider instance) {
    this.withProvider(instance.getProvider()); 
  }
  private AuthorizationPolicyExtensionProviderBuilder provider;
  
  /**
   * This method has been deprecated, please use method buildProvider instead.
   * @return The buildable object.
   */
  @Deprecated
  public AuthorizationPolicyExtensionProvider getProvider() {
    return this.provider!=null ?this.provider.build():null;
  }
  public AuthorizationPolicyExtensionProvider buildProvider() {
    return this.provider!=null ?this.provider.build():null;
  }
  public A withProvider(AuthorizationPolicyExtensionProvider provider) {
    _visitables.get("provider").remove(this.provider);
    if (provider!=null){ this.provider= new AuthorizationPolicyExtensionProviderBuilder(provider); _visitables.get("provider").add(this.provider);} else { this.provider = null; _visitables.get("provider").remove(this.provider); } return (A) this;
  }
  public Boolean hasProvider() {
    return this.provider != null;
  }
  public A withNewProvider(String name) {
    return (A)withProvider(new AuthorizationPolicyExtensionProvider(name));
  }
  public AuthorizationPolicyProviderFluent.ProviderNested<A> withNewProvider() {
    return new AuthorizationPolicyProviderFluentImpl.ProviderNestedImpl();
  }
  public AuthorizationPolicyProviderFluent.ProviderNested<A> withNewProviderLike(AuthorizationPolicyExtensionProvider item) {
    return new AuthorizationPolicyProviderFluentImpl.ProviderNestedImpl(item);
  }
  public AuthorizationPolicyProviderFluent.ProviderNested<A> editProvider() {
    return withNewProviderLike(getProvider());
  }
  public AuthorizationPolicyProviderFluent.ProviderNested<A> editOrNewProvider() {
    return withNewProviderLike(getProvider() != null ? getProvider(): new AuthorizationPolicyExtensionProviderBuilder().build());
  }
  public AuthorizationPolicyProviderFluent.ProviderNested<A> editOrNewProviderLike(AuthorizationPolicyExtensionProvider item) {
    return withNewProviderLike(getProvider() != null ? getProvider(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    AuthorizationPolicyProviderFluentImpl that = (AuthorizationPolicyProviderFluentImpl) o;
    if (provider != null ? !provider.equals(that.provider) :that.provider != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(provider,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (provider != null) { sb.append("provider:"); sb.append(provider); }
    sb.append("}");
    return sb.toString();
  }
  class ProviderNestedImpl<N> extends AuthorizationPolicyExtensionProviderFluentImpl<AuthorizationPolicyProviderFluent.ProviderNested<N>> implements AuthorizationPolicyProviderFluent.ProviderNested<N>,Nested<N>{
    ProviderNestedImpl(AuthorizationPolicyExtensionProvider item) {
      this.builder = new AuthorizationPolicyExtensionProviderBuilder(this, item);
    }
    ProviderNestedImpl() {
      this.builder = new AuthorizationPolicyExtensionProviderBuilder(this);
    }
    AuthorizationPolicyExtensionProviderBuilder builder;
    public N and() {
      return (N) AuthorizationPolicyProviderFluentImpl.this.withProvider(builder.build());
    }
    public N endProvider() {
      return and();
    }
    
  }
  
}

==> istio-model-v1beta1-6.7.1-sources.jar: io/fabric8/istio/api/security/v1beta1/AuthorizationPolicyProviderFluentImpl.java <==
package io.fabric8.istio.api.security.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class AuthorizationPolicyProviderFluentImpl<A extends AuthorizationPolicyProviderFluent<A>> extends BaseFluent<A> implements AuthorizationPolicyProviderFluent<A>{
  public AuthorizationPolicyProviderFluentImpl() {
  }
  public AuthorizationPolicyProviderFluentImpl(AuthorizationPolicyProvider instance) {
    if (instance != null) {
      this.withProvider(instance.getProvider());
    }
  }
  private AuthorizationPolicyExtensionProviderBuilder provider;
  
  /**
   * This method has been deprecated, please use method buildProvider instead.
   * @return The buildable object.
   */
  @Deprecated
  public AuthorizationPolicyExtensionProvider getProvider() {
    return this.provider!=null ?this.provider.build():null;
  }
  public AuthorizationPolicyExtensionProvider buildProvider() {
    return this.provider!=null ?this.provider.build():null;
  }
  public A withProvider(AuthorizationPolicyExtensionProvider provider) {
    _visitables.get("provider").remove(this.provider);
    if (provider!=null){ this.provider= new AuthorizationPolicyExtensionProviderBuilder(provider); _visitables.get("provider").add(this.provider);} else { this.provider = null; _visitables.get("provider").remove(this.provider); } return (A) this;
  }
  public Boolean hasProvider() {
    return this.provider != null;
  }
  public A withNewProvider(String name) {
    return (A)withProvider(new AuthorizationPolicyExtensionProvider(name));
  }
  public AuthorizationPolicyProviderFluentImpl.ProviderNested<A> withNewProvider() {
    return new AuthorizationPolicyProviderFluentImpl.ProviderNestedImpl();
  }
  public AuthorizationPolicyProviderFluentImpl.ProviderNested<A> withNewProviderLike(AuthorizationPolicyExtensionProvider item) {
    return new AuthorizationPolicyProviderFluentImpl.ProviderNestedImpl(item);
  }
  public AuthorizationPolicyProviderFluentImpl.ProviderNested<A> editProvider() {
    return withNewProviderLike(getProvider());
  }
  public AuthorizationPolicyProviderFluentImpl.ProviderNested<A> editOrNewProvider() {
    return withNewProviderLike(getProvider() != null ? getProvider(): new AuthorizationPolicyExtensionProviderBuilder().build());
  }
  public AuthorizationPolicyProviderFluentImpl.ProviderNested<A> editOrNewProviderLike(AuthorizationPolicyExtensionProvider item) {
    return withNewProviderLike(getProvider() != null ? getProvider(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AuthorizationPolicyProviderFluentImpl that = (AuthorizationPolicyProviderFluentImpl) o;
    if (!java.util.Objects.equals(provider, that.provider)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(provider,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (provider != null) { sb.append("provider:"); sb.append(provider); }
    sb.append("}");
    return sb.toString();
  }
  class ProviderNestedImpl<N> extends AuthorizationPolicyExtensionProviderFluentImpl<AuthorizationPolicyProviderFluentImpl.ProviderNested<N>> implements AuthorizationPolicyProviderFluentImpl.ProviderNested<N>,Nested<N>{
    ProviderNestedImpl(AuthorizationPolicyExtensionProvider item) {
      this.builder = new AuthorizationPolicyExtensionProviderBuilder(this, item);
    }
    ProviderNestedImpl() {
      this.builder = new AuthorizationPolicyExtensionProviderBuilder(this);
    }
    AuthorizationPolicyExtensionProviderBuilder builder;
    public N and() {
      return (N) AuthorizationPolicyProviderFluentImpl.this.withProvider(builder.build());
    }
    public N endProvider() {
      return and();
    }
    
  }
  
}
